@@ -32,7 +32,7 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-#define MediaInfo_Version_GUI __T("25.09.20251005")
+#define MediaInfo_Version_GUI __T("25.09.20251103")
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
@@ -94,6 +94,10 @@ public:
     ZenLib::ZtringListList  SponsorUrl;
     ZenLib::ZtringListList  SponsorBanner;
     ZenLib::ZtringListList  SponsorBannerClickUrl;
+    ZenLib::ZtringListList  SponsorMessageWeight;
+    ZenLib::ZtringListList  SponsorBannerWeight;
+    size_t                  SponsorMessageIndex;
+    size_t                  SponsorBannerIndex;
 
     //Plugins
     ZenLib::Ztring GraphPluginURL;
